From f17de30cdf84aacd8975d1b3c2ed102a605887fa Mon Sep 17 00:00:00 2001
From: Peter Smith <peter.b.smith@fujitsu.com>
Date: Mon, 18 Jan 2021 21:36:27 +1100
Subject: [PATCH v16] Tablesync extra logging.

This patch only adds some extra logging which may be helpful for testing, but is not for committing.
---
 src/backend/replication/logical/tablesync.c | 53 +++++++++++++++++++++++++----
 src/backend/tcop/postgres.c                 |  2 ++
 2 files changed, 49 insertions(+), 6 deletions(-)

diff --git a/src/backend/replication/logical/tablesync.c b/src/backend/replication/logical/tablesync.c
index cde3297..21f686c 100644
--- a/src/backend/replication/logical/tablesync.c
+++ b/src/backend/replication/logical/tablesync.c
@@ -282,8 +282,8 @@ tablesync_cleanup_at_interrupt(void)
 	Oid			subid = MySubscription->oid;
 	Oid			relid = MyLogicalRepWorker->relid;
 
-	elog(DEBUG1,
-		 "tablesync_cleanup_at_interrupt for relid = %d",
+	elog(LOG,
+		 "!!>> tablesync_cleanup_at_interrupt for relid = %d",
 		 MyLogicalRepWorker->relid);
 
 
@@ -324,7 +324,13 @@ tablesync_cleanup_at_interrupt(void)
 
 		ReplicationSlotNameForTablesync(subid, relid, syncslotname);
 
+		elog(LOG,
+			 "!!>> tablesync_cleanup_at_interrupt: dropping the tablesync slot \"%s\".",
+			 syncslotname);
 		ReplicationSlotDropAtPubNode(wrconn, syncslotname, missing_ok);
+		elog(LOG,
+			 "!!>> tablesync_cleanup_at_interrupt: dropped the tablesync slot \"%s\".",
+			 syncslotname);
 	}
 
 	/*
@@ -341,7 +347,13 @@ tablesync_cleanup_at_interrupt(void)
 	originid = replorigin_by_name(originname, true);
 	if (originid != InvalidRepOriginId)
 	{
+		elog(LOG,
+			 "!!>> tablesync_cleanup_at_interrupt: dropping origin tracking for \"%s\"",
+			 originname);
 		replorigin_drop(originid, false);
+		elog(LOG,
+			 "!!>> tablesync_cleanup_at_interrupt: dropped origin tracking for \"%s\"",
+			 originname);
 		/*
 		 * CommitTransactionCommand would normally attempt to advance the origin
 		 * but now that the origin is dropped that would fail, so we need to reset
@@ -387,10 +399,13 @@ process_syncing_tables_for_sync(XLogRecPtr current_lsn)
 		 */
 		ReplicationSlotNameForTablesync(subid, relid, syncslotname);
 
-		elog(DEBUG1,
+		elog(LOG,
 			 "process_syncing_tables_for_sync: dropping the tablesync slot \"%s\".",
 			 syncslotname);
 		ReplicationSlotDropAtPubNode(wrconn, syncslotname, false);
+		elog(LOG,
+			 "!!>> process_syncing_tables_for_sync: dropped the tablesync slot \"%s\".",
+			 syncslotname);
 
 		/*
 		 * Change state to SYNCDONE.
@@ -559,10 +574,13 @@ process_syncing_tables_for_apply(XLogRecPtr current_lsn)
 					originid = replorigin_by_name(originname, true);
 					if (OidIsValid(originid))
 					{
-						elog(DEBUG1,
+						elog(LOG,
 							 "process_syncing_tables_for_apply: dropping tablesync origin tracking for \"%s\".",
 							 originname);
 						replorigin_drop(originid, false);
+						elog(LOG,
+							 "!!>> process_syncing_tables_for_apply: dropped tablesync origin tracking for \"%s\".",
+							 originname);
 					}
 				}
 
@@ -1061,14 +1079,22 @@ LogicalRepSyncTableStart(XLogRecPtr *origin_startpos)
 		 * The COPY phase was previously done, but tablesync then crashed/etc
 		 * before it was able to finish normally.
 		 */
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: tablesync relstate was SUBREL_STATE_FINISHEDCOPY.");
 		StartTransactionCommand();
 
 		/*
 		 * The origin tracking name must already exist (missing_ok=false).
 		 */
 		originid = replorigin_by_name(originname, false);
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: 2 replorigin_session_setup \"%s\".",
+			 originname);
 		replorigin_session_setup(originid);
 		replorigin_session_origin = originid;
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: 2 replorigin_session_get_progress \"%s\".",
+			 originname);
 		*origin_startpos = replorigin_session_get_progress(false);
 
 		goto copy_table_done;
@@ -1117,6 +1143,9 @@ LogicalRepSyncTableStart(XLogRecPtr *origin_startpos)
 	 * for the catchup phase after COPY is done, so tell it to use the
 	 * snapshot to make the final data consistent.
 	 */
+	elog(LOG,
+		 "!!>> LogicalRepSyncTableStart: walrcv_create_slot for \"%s\".",
+		 slotname);
 	walrcv_create_slot(wrconn, slotname, false,
 					   CRS_USE_SNAPSHOT, origin_startpos);
 
@@ -1148,10 +1177,13 @@ LogicalRepSyncTableStart(XLogRecPtr *origin_startpos)
 		 * If something failed during copy table then cleanup the created
 		 * slot.
 		 */
-		elog(DEBUG1,
+		elog(LOG,
 			 "LogicalRepSyncTableStart: tablesync copy failed. Dropping the tablesync slot \"%s\".",
 			 slotname);
 		ReplicationSlotDropAtPubNode(wrconn, slotname, false);
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: tablesync copy failed. Dropped the tablesync slot \"%s\".",
+			 slotname);
 
 		pfree(slotname);
 		slotname = NULL;
@@ -1172,11 +1204,20 @@ LogicalRepSyncTableStart(XLogRecPtr *origin_startpos)
 		 * replication origin from vanishing while advancing.
 		 */
 		LockRelationOid(ReplicationOriginRelationId, RowExclusiveLock);
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: 1 replorigin_create \"%s\".",
+			 originname);
 		originid = replorigin_create(originname);
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: 1 replorigin_advance \"%s\".",
+			 originname);
 		replorigin_advance(originid, *origin_startpos, InvalidXLogRecPtr,
 						   true /* go backward */ , true /* WAL log */ );
 		UnlockRelationOid(ReplicationOriginRelationId, RowExclusiveLock);
 
+		elog(LOG,
+			 "!!>> LogicalRepSyncTableStart: 1 replorigin_session_setup \"%s\".",
+			 originname);
 		replorigin_session_setup(originid);
 		replorigin_session_origin = originid;
 	}
@@ -1199,7 +1240,7 @@ LogicalRepSyncTableStart(XLogRecPtr *origin_startpos)
 
 copy_table_done:
 
-	elog(DEBUG1,
+	elog(LOG,
 		 "LogicalRepSyncTableStart: '%s' origin_startpos lsn %X/%X",
 		 originname,
 		 (uint32) (*origin_startpos >> 32),
diff --git a/src/backend/tcop/postgres.c b/src/backend/tcop/postgres.c
index ede6c2c..d267eee 100644
--- a/src/backend/tcop/postgres.c
+++ b/src/backend/tcop/postgres.c
@@ -3084,6 +3084,8 @@ ProcessInterrupts(void)
 					 errmsg("terminating autovacuum process due to administrator command")));
 		else if (IsLogicalWorker())
 		{
+			elog(LOG, "!!>> ProcessInterrupts: Hello, I am a LogicalWorker");
+
 			/* Tablesync workers do their own cleanups. */
 			if (IsLogicalWorkerTablesync())
 				tablesync_cleanup_at_interrupt(); /* does not return. */
-- 
1.8.3.1

